@@ -5,9 +5,10 @@ import os.path
 
 import pytest
 
+from pex.bin.pex import make_relative_to_root
 from pex.orderedset import OrderedSet
 from pex.pex_info import PexInfo
-from pex.variables import Variables
+from pex.variables import ENV, Variables
 
 
 def make_pex_info(requirements):
@@ -47,6 +48,14 @@ def test_from_empty_env():
   assert_same_info(PexInfo(info=info), PexInfo.from_env(env=environ))
 
 
+def test_make_relative():
+  with ENV.patch(PEX_ROOT='/pex_root'):
+    assert '/pex_root/interpreters' == make_relative_to_root('{pex_root}/interpreters')
+
+    #Verify the user can specify arbitrary absolute paths.
+    assert '/tmp/interpreters' == make_relative_to_root('/tmp/interpreters')
+
+
 def test_from_env():
   pex_root = os.path.realpath('/pex_root')
   environ = dict(PEX_ROOT=pex_root,
